# wsssss: Walter's set of scripts for studying simulated stars.

This repository contains a package which make creating, running, and studying grids of stars with MESA quick 
(except for the compute time) and easy. 

Install with
`pip install wsssss`

`inlists.create_grid` and `mesa-go` require a version of [MESA](https://docs.mesastar.org) to be installed.
`gyre-driver` requires a version of [gyre](https://gyre.readthedocs.io/en/stable/) to be installed.

Documentation is available at [https://wsssss.readthedocs.io](https://wsssss.readthedocs.io).